Ocyan plugin Oscar sequential order numbers
===========================================

About Oscar sequential order numbers
------------------------------------
Generates sequential order numbers.
It uses the sequence or autoincement for the id field of Sequence model.
Start from a specific number by inserting the number into the DB. This will
only work if it is the largest number so far.

Installation
------------
Add `ocyan.plugin.oscar_sequential_order_numbers` to your projects dependencies.


Setting a starting point
------------------------
Use the `set_latest_order_number` management command to set the last currently used order number.
```
manage.py set_latest_order_number 123
```

It does make sure if it is actually higher then the existing values.
